@@ -144,7 +144,7 @@ def preAuthenticate(uri, answer_url,
 		response=HttpResponse()
 		response['Location']=redirect_url
 		response.status_code=303
-		return response, claimedId
+		return response
 	else:
 		raise IncorrectClaimError()
 
@@ -159,12 +159,10 @@ class Backend:
 		global maxTimeShift, maxLoginDelay
 
 		# the default way for telling Django that this auth backend does not fit
-		if not ("request" in credentials and "claim" in credentials):
+		if not ("openidrequest" in credentials):
 			raise TypeError
 
-		request=credentials['request']
-		claimedId=credentials['claim']
-		
+		request=credentials['openidrequest']
 		query=request.META['QUERY_STRING']
 		handle = request.GET['openid.assoc_handle']
 		session=getSessionByHandle(handle)
@@ -183,7 +181,7 @@ class Backend:
 			raise ReplayAttackError()
 		storeNonce(nonce)
 
-		# provider-based auth returns claim id, OpenID not (if I got that right) - in this case we take the original value
+		# provider-based auth returns claim id, OpenID not (if I got that right) - in this case we take the one stored in the session found by assocHandle
 		if 'openid.claimed_id' in request.GET:
 			if 'claimed_id' not in signed:
 				raise IncompleteAnswerError()
@@ -191,6 +189,7 @@ class Backend:
 		else:
 			if 'identity' not in signed:
 				raise IncompleteAnswerError()
+			claimedId = session.claimedId
 
 		# look up OpenID claim string in local database
 		idrecord=UserOpenID.objects.filter(Q(uri=claimedId))
